@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0814';
+our $VERSION = '0.0815';
 
 use Moo;
 use strictures 2;
@@ -190,6 +190,7 @@ sub motif {
 
 sub motifs {
     my ($self, $n) = @_;
+    $n ||= 1;
     my @motifs = map { $self->motif } 1 .. $n;
     return @motifs;
 }
@@ -231,7 +232,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0814
+version 0.0815
 
 =head1 SYNOPSIS
 
@@ -255,8 +256,8 @@ version 0.0814
     groups => [   1, 1, 3   ],
   );
 
-  my $motif  = $mdp->motif;  # list-ref of pool members
-  my @motifs = $mdp->motifs; # list of motifs
+  my $motif  = $mdp->motif;     # list-ref of pool members
+  my @motifs = $mdp->motifs(4); # list of motifs
 
 =head1 DESCRIPTION
 
@@ -379,10 +380,13 @@ application, in a loop until the B<size> is met.
 
 =head2 motifs
 
+  @motifs = $mdp->motifs;
   @motifs = $mdp->motifs($n);
 
 Return B<n> motifs.
 
+Default: C<n=1>
+
 =head2 add_to_score
 
   $mdp->add_to_score($score, $motif, $pitches);
